netapp_ontap.models.consistency_group_snapshot_response_records API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_snapshot_response_records`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupSnapshotResponseRecordsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupSnapshotResponseRecords object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `comment: str GET POST`

    Comment for the snapshot.

    Example: My snapshot comment

  `consistency_group: ConsistencyGroup GET`

    The consistency_group field of the consistency_group_snapshot_response_records.

  `consistency_type: str GET POST PATCH`

    Consistency type. This is for categorization purposes only. A snapshot should not be set to 'application consistent' unless the host application is quiesced for the snapshot. Valid in POST.

    Valid choices:

    - crash
    - application
  `create_time: ImpreciseDateTime GET`

    Time the snapshot copy was created

    Example: 2020-10-25T11:20:00.000+0000

  `is_partial: bool GET`

    Indicates whether the snapshot taken is partial or not.

    Example: false

  `links: SelfLink GET`

    The links field of the consistency_group_snapshot_response_records.

  `luns: List[ConsistencyGroupSnapshotLuns] GET`

    The list of LUNs in this snapshot.

  `missing_luns: List[Lun] GET`

    List of LUNs that are not in the snapshot.

  `missing_namespaces: List[ConsistencyGroupSnapshotMissingNamespaces] GET`

    List of NVMe namespaces that are not in the snapshot.

  `missing_volumes: List[Volume] GET`

    List of volumes which are not in the snapshot.

  `name: str GET POST PATCH`

    Name of the snapshot.

  `namespaces: List[ConsistencyGroupSnapshotMissingNamespaces] GET`

    The list of NVMe namespaces in this snapshot.

  `reclaimable_space: Size GET`

    Space reclaimed when the snapshot is deleted, in bytes.

  `restore_size: Size GET`

    Size of the consistency group if this snapshot is restored.

    Example: 4096

  `snaplock: ConsistencyGroupSnapshotSnaplock GET POST PATCH`

    SnapLock Snapshot attributes.

  `snapmirror_label: str GET POST`

    Snapmirror Label for the snapshot.

    Example: sm_label

  `snapshot_volumes: List[ConsistencyGroupVolumeSnapshot] GET`

    List of volume and snapshot identifiers for each volume in the snapshot.

  `svm: Svm GET POST PATCH`

    The SVM in which the consistency group is located.

  `uuid: str GET`

    The unique identifier of the snapshot. The UUID is generated by ONTAP when the snapshot is created.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412

  `write_fence: bool GET POST`

    Specifies whether a write fence will be taken when creating the snapshot. The default is false if there is only one volume in the consistency group, otherwise the default is true.